@@ -6,13 +6,15 @@ import os
 import sys
 
 import logzero
-import toml
 from logzero import logger
+import toml
 
 from varfish_cli import __version__
-from .common import run_nocmd, CommonConfig
-from .case import setup_argparse as setup_argparse_case
-from .case import run as run_case
+from varfish_cli.case import run as run_case
+from varfish_cli.case import setup_argparse as setup_argparse_case
+from varfish_cli.common import CommonConfig, run_nocmd
+from varfish_cli.varannos import run as run_varannos
+from varfish_cli.varannos import setup_argparse as setup_argparse_varannos
 
 #: Paths to search the global configuration in.
 GLOBAL_CONFIG_PATHS = ("~/.varfishrc.toml",)
@@ -61,6 +63,7 @@ def setup_argparse():
     subparsers = parser.add_subparsers(dest="cmd")
 
     setup_argparse_case(subparsers.add_parser("case", help="Work with cases."))
+    setup_argparse_varannos(subparsers.add_parser("varannos", help="Work with varannos module."))
 
     return parser, subparsers
 
@@ -104,7 +107,7 @@ def main(argv=None):
     config = CommonConfig.create(args, toml_config)
 
     # Handle the actual command line.
-    cmds = {None: run_nocmd, "case": run_case}
+    cmds = {None: run_nocmd, "case": run_case, "varannos": run_varannos}
 
     res = cmds[args.cmd](
         config, toml_config, args, parser, subparsers.choices[args.cmd] if args.cmd else None
